# File-Name:       MSBVAR JCR Gaza Paper              
# Date:            2009-09-12                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:      
# Packages Used:    vars,foreign,MASS,tseries,urca,apsrtable,stats,MSBVAR          
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac


library(vars)
library(foreign)
library(MASS)
library(tseries)
library(urca)
library(apsrtable)
library(stats)
library(MSBVAR)

###Reading the Data into
unscaled<-read.dta(file="Gaza_no_postures.dta")
summary(unscaled)
Israel<-unscaled$israel
sd(Israel)
Hamas<-unscaled$hamas
sd(Hamas)
hours<-unscaled$hours




###Setting up the data and standardizing where hamas and israel residuals are equal to 1 (for IRF analysis)


israel.gaza<-cbind(Hamas,Israel)
israel.ts<-ts(data=israel.gaza, start = 1, end = 598, frequency = 1)


###Creating Exogenous variables and checking different lag lengths#######

###Setting up the exogenous variables
x<-seq(1, 1, length.out=173)
z<-seq(0,0,length.out=425)
prewar<-append(x,z)
r<-seq(1,1,length.out=305)
f<-seq(0,0,length.out=293)
preun<-append(r,f)

###Exogenous variables
exog=cbind(prewar,preun)
israel.gaza<-cbind(Hamas,Israel)
hamas.gaza<-cbind(Israel,Hamas)
israel.ts<-ts(data=israel.gaza, start = 1, end = 598, frequency = 1)
hamas.ts<-ts(data=hamas.gaza, start = 1, end = 598, frequency = 1)
###Checking lag length
var.lag.specification(israel.ts, lagmax = 25) 


### Estimating the model in VARS################

###The 5-lag model
short.vars<-VAR(israel.gaza,p=5)
summary(short.vars)

###Residual Sum of Squares for whole Conflict
resids<-resid(short.vars)
rss_hamas_whole<-sum(resids[,1]^2)
rss_hamas_whole
rss_israel_whole<-sum(resids[,2]^2)
rss_israel_whole





###Subsetting the data before the Invasion
pre.invasion<-subset(unscaled,unscaled$hours<174)
israel<-pre.invasion$israel
hamas<-pre.invasion$hamas




###Creating the Pre-Invasion Data Set and its VAR
pre.war<-cbind(hamas,israel)
pre.war.var<- VAR(pre.war, p=5)
summary(pre.war.var)
###REsidual sum of squares for pre Invasion
resids<-resid(pre.war.var)
rss_hamas_pre_inv<-sum(resids[,1]^2)
rss_hamas_pre_inv
rss_israel_pre_inv<-sum(resids[,2]^2)
rss_israel_pre_inv

###Subsetting the data after the Invasion
invasion<-subset(unscaled,unscaled$hours>=174)
israel<-invasion$israel
hamas<-invasion$hamas


##Creating the post Invasion data set
war<-cbind(hamas,israel)
war.var<-VAR(war,p=5)
summary(war.var)
###REsidual sum of squares for post Invasion
resids<-resid(war.var)
rss_hamas_post_inv<-sum(resids[,1]^2)
rss_hamas_post_inv
rss_israel_post_inv<-sum(resids[,2]^2)
rss_israel_post_inv

###Creating the pre-UN Security council vote
pre.un<-subset(unscaled,unscaled$hours<306)
israel<-pre.un$israel
hamas<-pre.un$hamas

###Creating the Pre-UN Sec. Council data set
pre.vote<-cbind(hamas,israel)
pre.vote.var<-VAR(pre.vote,p=5)
summary(pre.vote.var)
###REsidual sum of squares for pre Vote
resids<-resid(pre.vote.var)
rss_hamas_pre_vote<-sum(resids[,1]^2)
rss_hamas_pre_vote
rss_israel_pre_vote<-sum(resids[,2]^2)
rss_israel_pre_vote

###Creating the Post-UN Sec. Council data set
post.un<-subset(unscaled,unscaled$hours>=306)
israel<-post.un$israel
hamas<-post.un$hamas

###Creating the Pre-UN Sec. Council data set
post.vote<-cbind(hamas,israel)
post.vote.var<-VAR(post.vote,p=5)
summary(post.vote.var)

###REsidual sum of squares for post Vote
resids<-resid(post.vote.var)
rss_hamas_post_vote<-sum(resids[,1]^2)
rss_hamas_post_vote
rss_israel_post_vote<-sum(resids[,2]^2)
rss_israel_post_vote

###Chi-Square Test
2*((-1344.938+-3322.305)+4737.933 )
2*((-2457.803+-2216.242)+4737.933)
###Chow Test 

###Hamas struc. break pre and post-Invasion:
((rss_hamas_whole-(rss_hamas_pre_inv+rss_hamas_post_inv))/11)/((rss_hamas_pre_inv+rss_hamas_post_inv)/(598-22))

##Israel struc. break pre and post Invasion:
((rss_israel_whole-(rss_israel_pre_inv+rss_israel_post_inv))/11)/((rss_israel_pre_inv+rss_israel_post_inv)/(598-22))

###Hamas struc. break pre and post-Vote:
((rss_hamas_whole-(rss_hamas_pre_vote+rss_hamas_post_vote))/11)/((rss_hamas_pre_vote+rss_hamas_post_vote)/(598-22))

###Israel struc. break pre and post-Vote:
((rss_israel_whole-(rss_israel_pre_vote+rss_israel_post_vote))/11)/((rss_israel_pre_vote+rss_israel_post_vote)/(598-22))