# File-Name:       MSBVAR JCR Gaza Paper              
# Date:            2009-09-12                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:      
# Packages Used:    vars,foreign,MASS,tseries,urca,apsrtable,stats,MSBVAR          
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac


library(vars)
library(foreign)
library(MASS)
library(tseries)
library(urca)
library(apsrtable)
library(stats)
library(MSBVAR)

###Reading the Data into R
unscaled<-read.dta(file="Gaza_no_postures.dta")

###Table 1 ####
summary(unscaled)
Israel<-unscaled$israel
sd(Israel)
Hamas<-unscaled$hamas
sd(Hamas)
hours<-unscaled$hours




###Setting up the data and standardizing where hamas and israel residuals are equal to 1 (for IRF analysis)


####Figure 1####
israel.gaza<-cbind(Hamas,Israel)
israel.ts<-ts(data=israel.gaza, start = 1, end = 598, frequency = 1)
###Plotting Israel
plot(Israel, xlab="hours", ylab="Israel conflict intensity", ylim=c(0,100),pch=8,col="blue",cex=.5)
lines(Israel,lwd=c(.75),lty=c(1),col=c("blue"))
text(525,35,"Israeli cease-fire", cex=.5)
text(180,90,"Ground Invasion Begins", cex=.5)
text(535,30,"Hamas cease-fire", cex=.5)
text(235,83,"UNRWA school hit", cex=.5)
text(312,75, "UN Secur. Coun.", cex=.5)
text(451,85, "IDF enter Gaza City", cex=.5)
text(355,70,"IAF hits Hamas targets",cex=.5)
text(30,87,"Op. begin w/ IAF strikes",cex=.5)
text(100,83,"Constant Hamas rockets",cex=.5)
###Plotting Hamas
plot(Hamas, xlab="hours", ylab="Hamas conflict intensity", ylim=c(0,100),pch=2,col="red",cex=.5)
lines(Hamas,lwd=c(.75),lty=c(1),col=c("red"))
text(525,45,"Israeli cease-fire", cex=.5)
text(180,70,"Ground Invasion Begins", cex=.5)
text(535,35,"Hamas cease-fire", cex=.5)
text(235,78,"UNRWA school hit", cex=.5)
text(312,37, "UN Secur. Coun.", cex=.5)
text(451,65, "IDF enter Gaza City", cex=.5)
text(355,65,"IAF hits Hamas targets",cex=.5)
text(32,47,"Op. begin w/ IAF strikes",cex=.5)
text(100,68,"Constant Hamas rockets",cex=.5)

###Creating Exogenous variables and checking different lag lengths#######

###Setting up the exogenous variables
x<-seq(1, 1, length.out=173)
z<-seq(0,0,length.out=425)
prewar<-append(x,z)
r<-seq(1,1,length.out=305)
f<-seq(0,0,length.out=293)
preun<-append(r,f)

###Exogenous variables
exog=cbind(prewar,preun)
israel.gaza<-cbind(Hamas,Israel)
hamas.gaza<-cbind(Israel,Hamas)
israel.ts<-ts(data=israel.gaza, start = 1, end = 598, frequency = 1)
hamas.ts<-ts(data=hamas.gaza, start = 1, end = 598, frequency = 1)

###Checking lag length Table 2
var.lag.specification(israel.ts, lagmax = 25) 

###Granger Test Table 3####
granger.test(israel.ts, 5)
granger.test(israel.ts, 9)
### Estimating the model in VARS################

###The 5-lag model
short.vars<-VAR(israel.gaza,p=5,exogen=exog)
summary(short.vars)

###The 9-lag model
vars<-VAR(israel.gaza,p=9,exogen=exog)
summary(vars)

### Using MSBVAR to estimate the model############

###The 5-lag model
short.MSBVAR <- reduced.form.var(israel.ts, p=5,z=exog) 
summary(short.MSBVAR)

###The 9-lag model
MSBVAR <- reduced.form.var(israel.ts, p=9,z=exog) 
summary(MSBVAR)


###Comparing models where Hamas and Israel are initially constrained at zero and their forecast error decomposition Tables  4 and 7 ####

israel.msbvar<- reduced.form.var(israel.ts, p=5)
hamas.msbvar<- reduced.form.var(hamas.ts, p=5)
israel.dfev<-dfev(israel.msbvar,k=12)
hamas.dfev<-dfev(hamas.msbvar,k=12)

summary(israel.dfev)
summary(hamas.dfev)

###Checking the Standard Deviation
sd(Israel)
sd(Hamas)

###Normalizing the data and dividing Hamas and Israel by their standard deviation to get IRF shocks=1  ###
israel<-Israel/sd(Israel)
hamas<-Hamas/sd(Hamas)

###Creating the data set for the scaled (standardized) conflict, and log of scaled
scaled<-data.frame(cbind(hours,hamas,israel))
summary(scaled)


hamas<-scaled$hamas
israel<-scaled$israel
log.hamas<-log(hamas+1)
log.israel<-log(israel+1)

israel.data<-cbind(hamas,israel)
hamas.data<-cbind(israel,hamas)
log.israel.data<-cbind(log.hamas,log.israel)
summary(log.israel.data)

israel.ts<-ts(data=israel.data, start = 1, end = 598, frequency = 1)
hamas.ts<-ts(data=hamas.data, start = 1, end = 598, frequency = 1)
log.israel.ts<-ts(data=log.israel.data, start = 1, end = 598, frequency = 1)

###Comparing Models for scaled and log scaled and hamas constrained at zero initially by ordering hamas first
israel.var<-reduced.form.var(israel.ts,p=5)
log.israel.var<-reduced.form.var(log.israel.ts,p=5)
hamas.var<-reduced.form.var(hamas.ts,p=5)

###Colnames
varnames <- colnames(israel.ts)
var.h<-colnames(hamas.ts)

###Subsetting the data before the Invasion
pre.invasion<-subset(scaled,scaled$hours<174)
israel<-pre.invasion$israel
hamas<-pre.invasion$hamas


###Creating the Pre-Invasion Data Set and its VAR
pre.war<-cbind(hamas,israel)
pre.war.ts<-ts(data=pre.war, start = 1, end = 173, frequency = 1)
var.lag.specification(pre.war.ts, lagmax = 25)
pre.war.var<- reduced.form.var(pre.war.ts, p=5)


###Subsetting the data after the Invasion
invasion<-subset(scaled,scaled$hours>=174)
israel<-invasion$israel
hamas<-invasion$hamas


##Creating the post Invasion data set
war<-cbind(hamas,israel)
war.ts<-ts(data=war, start = 1, end = 425, frequency = 1)
var.lag.specification(war.ts, lagmax = 25)
war.var<-reduced.form.var(war.ts,p=5)

###Creating the pre-UN Security council vote
pre.un<-subset(scaled,scaled$hours<306)
israel<-pre.un$israel
hamas<-pre.un$hamas

###Creating the Pre-UN Sec. Council data set
pre.vote<-cbind(hamas,israel)
pre.vote.ts<-ts(data=pre.vote, start = 1, end = 305, frequency = 1)
var.lag.specification(pre.vote.ts, lagmax = 25)
pre.vote.var<-reduced.form.var(pre.vote.ts,p=5)

###Creating the Post-UN Sec. Council data set
post.un<-subset(scaled,scaled$hours>=306)
israel<-post.un$israel
hamas<-post.un$hamas

###Creating the Pre-UN Sec. Council data set
post.vote<-cbind(hamas,israel)
post.vote.ts<-ts(data=post.vote, start = 1, end = 293, frequency = 1)
var.lag.specification(post.vote.ts, lagmax = 25)
post.vote.var<-reduced.form.var(post.vote.ts,p=5)

###Plotting the IRF's

##The Whole Conflict
israel.impulses<- mc.irf(israel.var, nsteps=20, draws=10000)
plot(israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)
log.israel.impulses<- mc.irf(log.israel.var, nsteps=20, draws=10000)
plot(log.israel.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)
hamas.impulses<-mc.irf(hamas.var, nsteps=20, draws=10000)
plot(hamas.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=var.h)

###Pre Invasion

pre.war.impulses <- mc.irf(pre.war.var, nsteps=20, draws=10000) 
plot(pre.war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Post Invasion

war.impulses <- mc.irf(war.var, nsteps=20, draws=10000) 
plot(war.impulses, method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Pre UN
pre.vote.impulses <- mc.irf(pre.vote.var, nsteps=20, draws=10000) 
plot(pre.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)

###Post UN
post.vote.impulses <- mc.irf(post.vote.var, nsteps=20, draws=10000) 
plot(post.vote.impulses,method=c("Percentile"), component=1, probs=c(0.025,0.975),varnames=varnames)
